import { ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { MarkdownService } from '../services/markdown.service';
import { WebSocketService } from '../services/websocket.service';

import { Message } from './message';
import { MessageControl } from './messagecontrol';

@Component({
  selector: 'app-messages',
  templateUrl: './messages.component.html',
  styleUrls: ['./messages.component.scss']
})
export class MessagesComponent implements OnInit {
  messages: Message[] = [];
  showNextButton = false;
  command_handlers = {'showbutton': this.showButton.bind(this)};

  constructor(
    private markdownService: MarkdownService,
    private websocketService: WebSocketService,
    private changeDetectorRef: ChangeDetectorRef
  ) {}

  convert(text: string) {
    return this.markdownService.convertToHtml(text);
  }

  showButton(data: MessageControl) {
    this.showNextButton = data.next_visibility;
  }

  ngOnInit() {
    this.websocketService.connect();
    this.websocketService.observeKey<Message>('message').subscribe(
      (event) => {
        this.messages.push(event.data);
        event.data.message = this.convert(event.data.message);
        this.changeDetectorRef.detectChanges();
      });
    this.websocketService.observeKey<MessageControl>('messagecontrol').subscribe(
      (event) => {
        this.command_handlers[event.data.command](event.data);
      });
  }
}
